@@ -5,7 +5,6 @@
 #' @inheritParams tern::g_lineplot
 #' @inheritParams tern::control_lineplot_vars
 #' @inheritParams template_arguments
-#' @param strata `r lifecycle::badge("deprecated")` Please use the `group_var` argument instead.
 #' @param group_var (`string` or `NA`)\cr group variable name.
 #' @param param (`character`)\cr parameter to filter the data by.
 #' @param incl_screen (`logical`)\cr whether the screening visit should be included.
@@ -23,7 +22,6 @@
 #'
 #' @keywords internal
 template_g_lineplot <- function(dataname = "ANL",
-                                strata = lifecycle::deprecated(),
                                 group_var = "ARM",
                                 x = "AVISIT",
                                 y = "AVAL",
@@ -42,14 +40,6 @@ template_g_lineplot <- function(dataname = "ANL",
                                 title = "Line Plot",
                                 y_lab = "",
                                 ggplot2_args = teal.widgets::ggplot2_args()) {
-  if (lifecycle::is_present(strata)) {
-    warning(
-      "The `strata` argument of `template_g_lineplot()` is deprecated as of teal.modules.clinical 0.9.1. ",
-      "Please use the `group_var` argument instead.",
-      call. = FALSE
-    )
-    group_var <- strata
-  }
 
   checkmate::assert_string(dataname)
   checkmate::assert_string(group_var)
@@ -106,7 +96,7 @@ template_g_lineplot <- function(dataname = "ANL",
   )
 
   z$variables <- substitute(
-    expr = variables <- control_lineplot_vars(x = x, y = y, group_var = arm, paramcd = paramcd, y_unit = y_unit),
+    expr = variables <- tern::control_lineplot_vars(x = x, y = y, group_var = arm, paramcd = paramcd, y_unit = y_unit),
     env = list(x = x, y = y, arm = group_var, paramcd = paramcd, y_unit = y_unit)
   )
 
@@ -151,7 +141,7 @@ template_g_lineplot <- function(dataname = "ANL",
   )
 
   plot_call <- substitute(
-    g_lineplot(
+    tern::g_lineplot(
       df = anl,
       variables = variables,
       interval = interval,
@@ -168,7 +158,7 @@ template_g_lineplot <- function(dataname = "ANL",
       y_lab = ggplot2_args_ylab,
       legend_title = ggplot2_args_legend_title,
       ggtheme = ggplot2::theme_minimal(),
-      control = control_analyze_vars(conf_level = conf_level),
+      control = tern::control_analyze_vars(conf_level = conf_level),
       subtitle_add_paramcd = FALSE,
       subtitle_add_unit = FALSE
     ),
@@ -212,6 +202,7 @@ template_g_lineplot <- function(dataname = "ANL",
 #' @inheritParams module_arguments
 #' @inheritParams teal::module
 #' @inheritParams template_g_lineplot
+#' @param strata `r lifecycle::badge("deprecated")` Please use the `group_var` argument instead.
 #'
 #' @inherit module_arguments return seealso
 #'
@@ -327,14 +318,11 @@ tm_g_lineplot <- function(label,
                           transformators = list(),
                           decorators = list()) {
   if (lifecycle::is_present(strata)) {
-    warning(
-      "The `strata` argument of `tm_g_lineplot()` is deprecated as of teal.modules.clinical 0.9.1. ",
-      "Please use the `group_var` argument instead.",
-      call. = FALSE
+    lifecycle::deprecate_stop(
+      when = "0.9.1",
+      what = "tm_g_lineplot(strata)",
+      with = "tm_g_lineplot(group_var)"
     )
-    group_var <- strata
-  } else {
-    strata <- group_var # resolves missing argument error
   }
 
   # Now handle 'parentname' calculation based on 'group_var'
@@ -421,9 +409,10 @@ ui_g_lineplot <- function(id, ...) {
     ),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
-      tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(a[c("group_var", "paramcd", "x", "y", "y_unit", "param")]),
       teal.transform::data_extract_ui(
         id = ns("param"),
@@ -475,9 +464,10 @@ ui_g_lineplot <- function(id, ...) {
         value = TRUE
       ),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "plot")),
-      teal.widgets::panel_group(
-        teal.widgets::panel_item(
-          "Additional plot settings",
+      bslib::accordion(
+        open = TRUE,
+        bslib::accordion_panel(
+          title = "Additional plot settings",
           teal.widgets::optionalSelectInput(
             ns("conf_level"),
             "Level of Confidence",
@@ -522,9 +512,10 @@ ui_g_lineplot <- function(id, ...) {
           )
         )
       ),
-      teal.widgets::panel_group(
-        teal.widgets::panel_item(
-          "Additional table settings",
+      bslib::accordion(
+        open = TRUE,
+        bslib::accordion_panel(
+          title = "Additional table settings",
           teal.widgets::optionalSliderInputValMinMax(
             ns("table_font_size"),
             "Table Font Size",
@@ -692,7 +683,7 @@ srv_g_lineplot <- function(id,
       id = "decorator",
       data = all_q,
       decorators = select_decorators(decorators, "plot"),
-      expr = print(plot)
+      expr = plot
     )
     plot_r <- reactive(decorated_all_q()[["plot"]])
 
@@ -730,7 +721,7 @@ srv_g_lineplot <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
