@@ -27,7 +27,7 @@ template_events_by_grade <- function(dataname,
                                      prune_diff = 0,
                                      add_total = TRUE,
                                      total_label = default_total_label(),
-                                     na_level = default_na_str(),
+                                     na_level = tern::default_na_str(),
                                      drop_arm_levels = TRUE,
                                      basic_table_args = teal.widgets::basic_table_args()) {
   checkmate::assert_string(dataname)
@@ -74,21 +74,21 @@ template_events_by_grade <- function(dataname,
   data_list <- add_expr(
     data_list,
     substitute(
-      expr = dataname <- df_explicit_na(dataname, na_level = na_str),
+      expr = dataname <- tern::df_explicit_na(dataname, na_level = na_str),
       env = list(dataname = as.name(dataname), na_str = na_level)
     )
   )
   data_list <- add_expr(
     data_list,
     substitute(
-      expr = dataname <- df_explicit_na(dataname, na_level = na_str),
+      expr = dataname <- tern::df_explicit_na(dataname, na_level = na_str),
       env = list(dataname = as.name("anl"), na_str = na_level)
     )
   )
   data_list <- add_expr(
     data_list,
     substitute(
-      expr = parentname <- df_explicit_na(parentname, na_level = na_str),
+      expr = parentname <- tern::df_explicit_na(parentname, na_level = na_str),
       env = list(parentname = as.name(parentname), na_str = na_level)
     )
   )
@@ -106,7 +106,7 @@ template_events_by_grade <- function(dataname,
 
   y$data <- bracket_expr(data_list)
 
-  y$layout_prep <- quote(split_fun <- trim_levels_in_group)
+  y$layout_prep <- quote(split_fun <- rtables::trim_levels_in_group)
 
   layout_list <- list()
 
@@ -157,7 +157,7 @@ template_events_by_grade <- function(dataname,
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = summarize_occurrences_by_grade(
+        expr = tern::summarize_occurrences_by_grade(
           var = grade,
           grade_groups = grade_groups,
           na_str = na_str
@@ -171,14 +171,14 @@ template_events_by_grade <- function(dataname,
             label_pos = "topleft",
             split_label = teal.data::col_labels(dataname[term_var])
           ) %>%
-          summarize_num_patients(
+          tern::summarize_num_patients(
             var = id,
             .stats = "unique",
             .labels = c("- Any Intensity -"),
             na_str = na_str
           ) %>%
-          count_occurrences_by_grade(var = grade, .indent_mods = -1L, na_str = na_str) %>%
-          append_varlabels(dataname, grade, indent = 1L),
+          tern::count_occurrences_by_grade(var = grade, .indent_mods = -1L, na_str = na_str) %>%
+          tern::append_varlabels(dataname, grade, indent = 1L),
         env = list(
           id = id,
           arm_var = arm_var,
@@ -193,7 +193,7 @@ template_events_by_grade <- function(dataname,
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = summarize_occurrences_by_grade(
+        expr = tern::summarize_occurrences_by_grade(
           var = grade,
           grade_groups = grade_groups,
           na_str = na_str
@@ -207,7 +207,7 @@ template_events_by_grade <- function(dataname,
             label_pos = "topleft",
             split_label = teal.data::col_labels(dataname[hlt])
           ) %>%
-          summarize_occurrences_by_grade(
+          tern::summarize_occurrences_by_grade(
             var = grade,
             grade_groups = grade_groups,
             na_str = na_str
@@ -221,14 +221,14 @@ template_events_by_grade <- function(dataname,
             label_pos = "topleft",
             split_label = teal.data::col_labels(dataname[llt])
           ) %>%
-          summarize_num_patients(
+          tern::summarize_num_patients(
             var = id,
             .stats = "unique",
             .labels = c("- Any Intensity -"),
             na_str = na_str
           ) %>%
-          count_occurrences_by_grade(var = grade, .indent_mods = -1L, na_str = na_str) %>%
-          append_varlabels(dataname, grade, indent = 2L),
+          tern::count_occurrences_by_grade(var = grade, .indent_mods = -1L, na_str = na_str) %>%
+          tern::append_varlabels(dataname, grade, indent = 2L),
         env = list(
           id = id,
           arm_var = arm_var,
@@ -314,7 +314,7 @@ template_events_by_grade <- function(dataname,
   sort_list <- list()
   scorefun <- if (add_total) {
     substitute(
-      expr = cont_n_onecol(length(levels(parent$arm_var)) + 1),
+      expr = rtables::cont_n_onecol(length(levels(parent$arm_var)) + 1),
       env = list(
         parent = as.name(parentname),
         arm_var = as.name(arm_var)
@@ -331,7 +331,7 @@ template_events_by_grade <- function(dataname,
       substitute(
         expr = {
           pruned_and_sorted_result <- pruned_result %>%
-            sort_at_path(path = term_var, scorefun = scorefun, decreasing = TRUE)
+            rtables::sort_at_path(path = term_var, scorefun = scorefun, decreasing = TRUE)
         },
         env = list(
           term_var = term_var,
@@ -345,8 +345,8 @@ template_events_by_grade <- function(dataname,
       substitute(
         expr = {
           pruned_and_sorted_result <- pruned_result %>%
-            sort_at_path(path = hlt, scorefun = scorefun, decreasing = TRUE) %>%
-            sort_at_path(path = c(hlt, "*", llt), scorefun = scorefun, decreasing = TRUE)
+            rtables::sort_at_path(path = hlt, scorefun = scorefun, decreasing = TRUE) %>%
+            rtables::sort_at_path(path = c(hlt, "*", llt), scorefun = scorefun, decreasing = TRUE)
         },
         env = list(
           llt = llt,
@@ -396,7 +396,7 @@ template_events_col_by_grade <- function(dataname,
                                          label_grade = NULL,
                                          prune_freq = 0.1,
                                          prune_diff = 0,
-                                         na_level = default_na_str(),
+                                         na_level = tern::default_na_str(),
                                          drop_arm_levels = TRUE,
                                          basic_table_args = teal.widgets::basic_table_args()) {
   checkmate::assert_string(dataname)
@@ -492,7 +492,7 @@ template_events_col_by_grade <- function(dataname,
   data_pipe <- add_expr(
     data_pipe,
     substitute(
-      expr = df_explicit_na(na_level = na_str),
+      expr = tern::df_explicit_na(na_level = na_str),
       env = list(na_str = na_level)
     )
   )
@@ -533,7 +533,10 @@ template_events_col_by_grade <- function(dataname,
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = rtables::split_cols_by(var = arm_var, split_fun = add_overall_level(total_label, first = FALSE)),
+        expr = rtables::split_cols_by(
+          var = arm_var,
+          split_fun = rtables::add_overall_level(total_label, first = FALSE)
+        ),
         env = list(
           arm_var = arm_var,
           total_label = total_label
@@ -566,7 +569,7 @@ template_events_col_by_grade <- function(dataname,
           hlt,
           child_labels = "visible",
           nested = FALSE,
-          split_fun = trim_levels_in_group(llt)
+          split_fun = rtables::trim_levels_in_group(llt)
         ),
         env = list(hlt = hlt, llt = llt)
       )
@@ -575,7 +578,7 @@ template_events_col_by_grade <- function(dataname,
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = append_varlabels(df = anl, vars = hlt),
+        expr = tern::append_varlabels(df = anl, vars = hlt),
         env = list(hlt = hlt)
       )
     )
@@ -584,7 +587,7 @@ template_events_col_by_grade <- function(dataname,
     layout_list <- add_expr(
       layout_list,
       substitute(
-        summarize_num_patients(
+        tern::summarize_num_patients(
           var = id,
           .stats = "unique",
           .labels = unique_label,
@@ -597,7 +600,7 @@ template_events_col_by_grade <- function(dataname,
   layout_list <- add_expr(
     layout_list,
     substitute(
-      analyze_vars(
+      tern::analyze_vars(
         llt,
         na.rm = FALSE,
         denom = "N_col",
@@ -612,7 +615,7 @@ template_events_col_by_grade <- function(dataname,
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = append_varlabels(df = anl, vars = llt),
+        expr = tern::append_varlabels(df = anl, vars = llt),
         env = list(llt = llt)
       )
     )
@@ -620,7 +623,7 @@ template_events_col_by_grade <- function(dataname,
     layout_list <- add_expr(
       layout_list,
       substitute(
-        expr = append_varlabels(df = anl, vars = llt, indent = 1L),
+        expr = tern::append_varlabels(df = anl, vars = llt, indent = 1L),
         env = list(llt = llt)
       )
     )
@@ -659,13 +662,13 @@ template_events_col_by_grade <- function(dataname,
   if (!is.null(hlt)) {
     sort_list <- add_expr(
       sort_list,
-      quote(scorefun_soc <- score_occurrences_cont_cols(col_indices = col_indices))
+      quote(scorefun_soc <- tern::score_occurrences_cont_cols(col_indices = col_indices))
     )
   }
 
   sort_list <- add_expr(
     sort_list,
-    quote(scorefun_term <- score_occurrences_cols(col_indices = col_indices))
+    quote(scorefun_term <- tern::score_occurrences_cols(col_indices = col_indices))
   )
 
   if (is.null(hlt)) {
@@ -674,7 +677,7 @@ template_events_col_by_grade <- function(dataname,
       substitute(
         expr = {
           sorted_result <- result %>%
-            sort_at_path(path = c(llt), scorefun = scorefun_term, decreasing = TRUE)
+            rtables::sort_at_path(path = c(llt), scorefun = scorefun_term, decreasing = TRUE)
         },
         env = list(llt = llt)
       )
@@ -685,8 +688,8 @@ template_events_col_by_grade <- function(dataname,
       substitute(
         expr = {
           sorted_result <- result %>%
-            sort_at_path(path = c(hlt), scorefun = scorefun_soc, decreasing = TRUE) %>%
-            sort_at_path(path = c(hlt, "*", llt), scorefun = scorefun_term, decreasing = TRUE)
+            rtables::sort_at_path(path = c(hlt), scorefun = scorefun_soc, decreasing = TRUE) %>%
+            rtables::sort_at_path(path = c(hlt, "*", llt), scorefun = scorefun_term, decreasing = TRUE)
         },
         env = list(
           hlt = hlt,
@@ -875,7 +878,7 @@ tm_t_events_by_grade <- function(label,
                                  prune_diff = 0,
                                  add_total = TRUE,
                                  total_label = default_total_label(),
-                                 na_level = default_na_str(),
+                                 na_level = tern::default_na_str(),
                                  drop_arm_levels = TRUE,
                                  pre_output = NULL,
                                  post_output = NULL,
@@ -943,9 +946,10 @@ ui_t_events_by_grade <- function(id, ...) {
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
-      tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(a[c("arm_var", "hlt", "llt", "grade")]),
       teal.transform::data_extract_ui(
         id = ns("arm_var"),
@@ -982,9 +986,10 @@ ui_t_events_by_grade <- function(id, ...) {
         value = a$col_by_grade
       ),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table")),
-      teal.widgets::panel_group(
-        teal.widgets::panel_item(
-          "Additional table settings",
+      bslib::accordion(
+        open = TRUE,
+        bslib::accordion_panel(
+          title = "Additional table settings",
           checkboxInput(
             ns("drop_arm_levels"),
             label = "Drop columns not in filtered analysis dataset",
@@ -1271,7 +1276,7 @@ srv_t_events_by_grade <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
