@@ -25,7 +25,7 @@ template_summary_by <- function(parentname,
                                 parallel_vars = FALSE,
                                 row_groups = FALSE,
                                 na.rm = FALSE, # nolint: object_name.
-                                na_level = default_na_str(),
+                                na_level = tern::default_na_str(),
                                 numeric_stats = c(
                                   "n", "mean_sd", "mean_ci", "median", "median_ci", "quantiles", "range"
                                 ),
@@ -61,7 +61,7 @@ template_summary_by <- function(parentname,
     data_list,
     substitute(
       expr = anl <- df %>%
-        df_explicit_na(omit_columns = setdiff(names(df), c(by_vars, sum_vars)), na_level = na_str),
+        tern::df_explicit_na(omit_columns = setdiff(names(df), c(by_vars, sum_vars)), na_level = na_str),
       env = list(
         df = as.name(dataname),
         by_vars = by_vars,
@@ -84,7 +84,7 @@ template_summary_by <- function(parentname,
   data_list <- add_expr(
     data_list,
     substitute(
-      expr = parentname <- df_explicit_na(parentname, na_level = na_str),
+      expr = parentname <- tern::df_explicit_na(parentname, na_level = na_str),
       env = list(parentname = as.name(parentname), na_str = na_level)
     )
   )
@@ -92,7 +92,7 @@ template_summary_by <- function(parentname,
   y$data <- bracket_expr(data_list)
 
   # Build layout
-  y$layout_prep <- quote(split_fun <- drop_split_levels)
+  y$layout_prep <- quote(split_fun <- rtables::drop_split_levels)
   if (row_groups) {
     y$layout_cfun <- quote(
       cfun_unique <- function(x, labelstr = "", .N_col) { # nolint: object_name.
@@ -123,7 +123,7 @@ template_summary_by <- function(parentname,
   split_cols_call <- lapply(arm_var, function(x) {
     if (drop_arm_levels) {
       substitute(
-        expr = rtables::split_cols_by(x, split_fun = drop_split_levels),
+        expr = rtables::split_cols_by(x, split_fun = rtables::drop_split_levels),
         env = list(x = x)
       )
     } else {
@@ -244,7 +244,7 @@ template_summary_by <- function(parentname,
       } else {
         if (length(var_labels > 0)) {
           substitute(
-            expr = analyze_vars(
+            expr = tern::analyze_vars(
               vars = sum_vars,
               var_labels = sum_var_labels,
               na.rm = na.rm,
@@ -256,7 +256,7 @@ template_summary_by <- function(parentname,
           )
         } else {
           substitute(
-            expr = analyze_vars(
+            expr = tern::analyze_vars(
               vars = sum_vars,
               na.rm = na.rm,
               na_str = na_level,
@@ -282,7 +282,7 @@ template_summary_by <- function(parentname,
           if (!inherits(tr, "TableRow") || inherits(tr, "LabelRow")) {
             return(FALSE)
           }
-          rvs <- unlist(unname(row_values(tr)))
+          rvs <- unlist(unname(rtables::row_values(tr)))
           isTRUE(all(rvs == 0))
         }
         table <- rtables::build_table(
@@ -412,7 +412,7 @@ tm_t_summary_by <- function(label,
                             parallel_vars = FALSE,
                             row_groups = FALSE,
                             useNA = c("ifany", "no"), # nolint: object_name.
-                            na_level = default_na_str(),
+                            na_level = tern::default_na_str(),
                             numeric_stats = c("n", "mean_sd", "median", "range"),
                             denominator = teal.transform::choices_selected(c("n", "N", "omit"), "omit", fixed = TRUE),
                             drop_arm_levels = TRUE,
@@ -503,9 +503,10 @@ ui_summary_by <- function(id, ...) {
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
     encoding = tags$div(
       ### Reporter
-      teal.reporter::simple_reporter_ui(ns("simple_reporter")),
+      teal.reporter::add_card_button_ui(ns("add_reporter"), label = "Add Report Card"),
+      tags$br(), tags$br(),
       ###
-      tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"), tags$br(),
       teal.transform::datanames_input(a[c("arm_var", "id_var", "paramcd", "by_vars", "summarize_vars")]),
       teal.transform::data_extract_ui(
         id = ns("arm_var"),
@@ -538,9 +539,10 @@ ui_summary_by <- function(id, ...) {
       ),
       checkboxInput(ns("parallel_vars"), "Show summarize variables in parallel", value = a$parallel_vars),
       checkboxInput(ns("row_groups"), "Summarize number of subjects in row groups", value = a$row_groups),
-      teal.widgets::panel_group(
-        teal.widgets::panel_item(
-          "Additional table settings",
+      bslib::accordion(
+        open = TRUE,
+        bslib::accordion_panel(
+          title = "Additional table settings",
           checkboxInput(ns("drop_zero_levels"), "Drop rows with 0 count", value = a$drop_zero_levels),
           radioButtons(
             ns("useNA"),
@@ -588,9 +590,10 @@ ui_summary_by <- function(id, ...) {
         )
       ),
       ui_decorate_teal_data(ns("decorator"), decorators = select_decorators(a$decorators, "table")),
-      teal.widgets::panel_group(
-        teal.widgets::panel_item(
-          "Additional Variables Info",
+      bslib::accordion(
+        open = TRUE,
+        bslib::accordion_panel(
+          title = "Additional Variables Info",
           teal.transform::data_extract_ui(
             id = ns("id_var"),
             label = "Subject Identifier",
@@ -696,7 +699,7 @@ srv_summary_by <- function(id,
       input_arm_var <- names(merged$anl_input_r()$columns_source$arm_var)
       input_id_var <- names(merged$anl_input_r()$columns_source$id_var)
       input_by_vars <- names(merged$anl_input_r()$columns_source$by_vars)
-      input_summarize_vars <- names(merged$anl_input_r()$columns_source$summarize_var)
+      input_summarize_vars <- names(merged$anl_input_r()$columns_source$summarize_vars)
       input_paramcd <- `if`(is.null(paramcd), NULL, unlist(paramcd$filter)["vars_selected"])
 
       # validate inputs
@@ -788,7 +791,7 @@ srv_summary_by <- function(id,
         card$append_src(source_code_r())
         card
       }
-      teal.reporter::simple_reporter_srv("simple_reporter", reporter = reporter, card_fun = card_fun)
+      teal.reporter::add_card_button_srv("add_reporter", reporter = reporter, card_fun = card_fun)
     }
     ###
   })
